==> sherpa_client-0.12.1.tar.gz: sherpa_client-0.12.1/sherpa_client/models/annotation_facets.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.label_count import LabelCount
    from ..models.text_count import TextCount


T = TypeVar("T", bound="AnnotationFacets")


@attr.s(auto_attribs=True)
class AnnotationFacets:
    """
    Attributes:
        labels (List['LabelCount']):
        texts (List['TextCount']):
    """

    labels: List["LabelCount"]
    texts: List["TextCount"]

    def to_dict(self) -> Dict[str, Any]:
        labels = []
        for labels_item_data in self.labels:
            labels_item = labels_item_data.to_dict()

            labels.append(labels_item)

        texts = []
        for texts_item_data in self.texts:
            texts_item = texts_item_data.to_dict()

            texts.append(texts_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "labels": labels,
                "texts": texts,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.label_count import LabelCount
        from ..models.text_count import TextCount

        d = src_dict.copy()
        labels = []
        _labels = d.pop("labels")
        for labels_item_data in _labels:
            labels_item = LabelCount.from_dict(labels_item_data)

            labels.append(labels_item)

        texts = []
        _texts = d.pop("texts")
        for texts_item_data in _texts:
            texts_item = TextCount.from_dict(texts_item_data)

            texts.append(texts_item)

        annotation_facets = cls(
            labels=labels,
            texts=texts,
        )

        return annotation_facets

==> sherpa_client-1.0.3.tar.gz: sherpa_client-1.0.3/sherpa_client/models/annotation_facets.py <==
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.label_count import LabelCount
    from ..models.text_count import TextCount


T = TypeVar("T", bound="AnnotationFacets")


@_attrs_define
class AnnotationFacets:
    """
    Attributes:
        labels (list['LabelCount']):
        texts (list['TextCount']):
    """

    labels: list["LabelCount"]
    texts: list["TextCount"]

    def to_dict(self) -> dict[str, Any]:
        labels = []
        for labels_item_data in self.labels:
            labels_item = labels_item_data.to_dict()
            labels.append(labels_item)

        texts = []
        for texts_item_data in self.texts:
            texts_item = texts_item_data.to_dict()
            texts.append(texts_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "labels": labels,
                "texts": texts,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.label_count import LabelCount
        from ..models.text_count import TextCount

        d = dict(src_dict)
        labels = []
        _labels = d.pop("labels")
        for labels_item_data in _labels:
            labels_item = LabelCount.from_dict(labels_item_data)

            labels.append(labels_item)

        texts = []
        _texts = d.pop("texts")
        for texts_item_data in _texts:
            texts_item = TextCount.from_dict(texts_item_data)

            texts.append(texts_item)

        annotation_facets = cls(
            labels=labels,
            texts=texts,
        )

        return annotation_facets
